@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** No Commercial Usage
-** This file contains pre-release code and may not be distributed.
-** You may use this file in accordance with the terms and conditions
-** contained in the Technology Preview License Agreement accompanying
-** this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in 
+** accordance with the Qt Commercial License Agreement provided with
+** the Software or, alternatively, in accordance with the terms
+** contained in a written agreement between you and Nokia.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**
-**
-**
-**
-**
-**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -65,18 +65,31 @@ QT_BEGIN_NAMESPACE
     \class QMediaRecorder
     \inmodule QtMultimediaKit
     \ingroup multimedia
-    \since 1.0
-
 
+    
     \brief The QMediaRecorder class is used for the recording of media content.
 
     The QMediaRecorder class is a high level media recording class.  It's not
     intended to be used alone but for accessing the media recording functions
     of other media objects, like QRadioTuner, or QAudioCaptureSource.
 
-    \snippet doc/src/snippets/multimedia-snippets/media.cpp Media recorder
+    \code
+    // Audio only recording
+    audioSource = new QAudioCaptureSource;
+    recorder = new QMediaRecorder(audioSource);
 
-    \sa QAudioCaptureSource
+    QAudioEncoderSettings audioSettings;
+    audioSettings.setCodec("audio/vorbis");
+    audioSettings.setQuality(QtMultimediaKit::HighQuality);
+
+    recorder->setEncodingSettings(audioSettings);
+
+    recorder->setOutputLocation(QUrl::fromLocalFile(fileName));
+    recorder->record();
+    \endcode
+
+
+    \sa
 */
 
 namespace
@@ -321,7 +334,7 @@ bool QMediaRecorder::setMediaObject(QMediaObject *object)
 
                 connect(service, SIGNAL(destroyed()), this, SLOT(_q_serviceDestroyed()));
 
-
+                
                 return true;
             }
         }
@@ -781,9 +794,6 @@ QVariant QMediaRecorder::metaData(QtMultimediaKit::MetaData key) const
 
 /*!
     Sets a \a value for a meta-data \a key.
-
-    \note To ensure that meta data is set corretly, it should be set before starting the recording.
-    Once the recording is stopped, any meta data set will be attached to the next recording.
 */
 void QMediaRecorder::setMetaData(QtMultimediaKit::MetaData key, const QVariant &value)
 {
